@@ -585,9 +585,16 @@ pub trait PanelState {
             Internal::escape => {
                 CmdResult::HandleInApp(Internal::escape)
             }
+            Internal::focus_staging_area_no_open => {
+                CmdResult::HandleInApp(Internal::focus_staging_area_no_open)
+            }
+            // panel_left depends on the kind of panel and is usually handled
+            // in a specific state, contrary to panel_left_no_open
             Internal::panel_left | Internal::panel_left_no_open => {
                 CmdResult::HandleInApp(Internal::panel_left_no_open)
             }
+            // panel_right depends on the kind of panel and is usually handled
+            // in a specific state, contrary to panel_right_no_open
             Internal::panel_right | Internal::panel_right_no_open => {
                 CmdResult::HandleInApp(Internal::panel_right_no_open)
             }
@@ -678,6 +685,9 @@ pub trait PanelState {
                 }
                 CmdResult::Keep
             }
+            internal if internal.is_input_related() => {
+                CmdResult::HandleInApp(internal)
+            }
             _ => CmdResult::Keep,
         })
     }
@@ -862,6 +872,7 @@ pub trait PanelState {
         app_state: &mut AppState,
         cc: &CmdContext,
     ) -> Result<CmdResult, ProgramError> {
+        info!("panel_state on_command {:?}", cc.cmd);
         self.clear_pending();
         let con = &cc.app.con;
         let screen = cc.app.screen;
