@@ -24,8 +24,6 @@ use {
 pub struct BrowserState {
     pub tree: Tree,
     pub filtered_tree: Option<Tree>,
-    // pub pending_pattern: InputPattern, // a pattern (or not) which has not yet be applied
-    // pub total_search_required: bool,   // whether the pending pattern should be in total search mode
     mode: Mode, // whether we're in 'input' or 'normal' mode
     pending_task: Option<BrowserTask>, // note: there are some other pending task, see
 }
@@ -102,7 +100,7 @@ impl BrowserState {
                 bs.displayed_tree_mut().try_select_path(&tree.selected_line().path);
             }
         }
-        CmdResult::from_optional_state(
+        CmdResult::from_optional_browser_state(
             new_state,
             message,
             in_new_panel,
@@ -148,7 +146,7 @@ impl BrowserState {
                 }
             }
             let dam = Dam::unlimited();
-            Ok(CmdResult::from_optional_state(
+            Ok(CmdResult::from_optional_browser_state(
                 BrowserState::new(
                     target,
                     if keep_pattern {
@@ -181,7 +179,7 @@ impl BrowserState {
         in_new_panel: bool,
     ) -> CmdResult {
         match &self.displayed_tree().selected_line().path.parent() {
-            Some(path) => CmdResult::from_optional_state(
+            Some(path) => CmdResult::from_optional_browser_state(
                 BrowserState::new(
                     path.to_path_buf(),
                     self.displayed_tree().options.without_pattern(),
@@ -563,6 +561,32 @@ impl PanelState for BrowserState {
                 self.displayed_tree_mut().try_select_last(page_height);
                 CmdResult::Keep
             }
+            Internal::show => {
+                let path = internal_path::determine_path(
+                    internal_exec,
+                    input_invocation,
+                    trigger_type,
+                    self.displayed_tree(),
+                    app_state,
+                    cc,
+                );
+                match path {
+                    Some(path) => {
+                        let res = self.displayed_tree_mut().show_path(&path, con);
+                        match res {
+                            Ok(()) => {
+                                let page_height = BrowserState::page_height(screen);
+                                self.displayed_tree_mut().make_selection_visible(page_height);
+                                CmdResult::Keep
+                            }
+                            Err(e) => CmdResult::DisplayError(format!("{e}")),
+                        }
+                    }
+                    None => {
+                        CmdResult::Keep
+                    }
+                }
+            }
             Internal::stage_all_directories => {
                 let pattern = self.displayed_tree().options.pattern.clone();
                 let file_type_condition = FileTypeCondition::Directory;
@@ -743,7 +767,7 @@ impl PanelState for BrowserState {
                     }
                 }
                 BrowserTask::StageAll { pattern, file_type_condition } => {
-                    info!("stage all pattern: {:?}", pattern);
+                    debug!("stage all pattern: {:?}", pattern);
                     let tree = self.displayed_tree();
                     let root = tree.root().clone();
                     let mut options = tree.options.clone();
@@ -757,7 +781,7 @@ impl PanelState for BrowserState {
                                 total_search,
                                 dam,
                                 |line| {
-                                    info!("??staging {:?}", &line.path);
+                                    debug!("??staging {:?}", &line.path);
                                     file_type_condition.accepts_path(&line.path)
                                 }
                             ))
